#include <Servo.h>  //Bibliothek zum ansteuern von Servo
#include <Adafruit_NeoPixel.h> //Bibliothek für den NeoPixel Ring
#include <Wire.h> //I2C Arduino Bibliothek

#define PIN 4 //digitaler PIN 12 an welchem der NeoPixel Ring angeschlossen ist

const int btnReset = 8; //Reset / Start Taster
const int btnUp = 9; //Taster Auf
const int btnDown = 11; //Taster Ab

const int servoWaitTime = 150;

boolean statusRun = false; //Status ob gerade ein Timer läuft.
int statusBtnUp = 0; //Status des Tasters für das Aufwärts zählen
int statusBtnDown = 0; //Status des Tasters für das Abwärts zählen
int statusBtnReset = 0; //Status des Tasters für den Reset bzw. Start

int activeNeoPixel = 0; // Zählvariable für den aktiven NeoPixel

int numPixels = 12; //max. Anzahl der NeoPixel

Adafruit_NeoPixel strip = Adafruit_NeoPixel(numPixels, PIN, NEO_GRB + NEO_KHZ800);

uint32_t red = strip.Color(255, 0, 0); //RGB Farbe Rot
uint32_t green = strip.Color(0, 255, 0); //RGB Farbe Grün
uint32_t blue = strip.Color(0, 0, 255); //RGB Farbe Blau
 
Servo drehservo; //Drehservo
Servo hebeservo; //Hebeservo

int position = 0; //Variable zum speichern von der aktuellen Position
const int waitTime = 50; //Zeit zum pausieren zwischen den einzelnen Schritten des Servos
int delayTime = 500;
double timerCounter = 0;

boolean hebelOben = false;
boolean drehstatusNormal = true;

boolean pixelBlinkAn = false;

void defaultServoStellung(){
  drehservo.write(0);  
  hebeservo.write(0);
  Serial.println("defaultServoStellung");
}

//Setzt alle NeoPixel in die Farbe Grün. 
//Und nur den aktiven auf die Farbe rot.
void drawRing(){
  for(uint16_t i=0; i<strip.numPixels(); i++){
    strip.setPixelColor(i, green); 
  }

  strip.setPixelColor(activeNeoPixel, red); 
  
  strip.show(); //Anzeigen
}


void setup(){ 
 Serial.begin(9600);
 hebeservo.attach(3);
 drehservo.attach(5);
 
 pinMode(btnUp,INPUT); //Setzen des Eingangssignals des Tasters
 pinMode(btnDown,INPUT); //Setzen des Eingangssignals des Tasters
 pinMode(btnReset,INPUT); //Setzen des Eingangssignals des Tasters

 defaultServoStellung();
 strip.begin();
 strip.setBrightness(5); //die Helligkeit setzen 0 dunke -> 255 ganz hell
 drawRing();
}
 
void loop(){
 drawRing();
 statusBtnUp = digitalRead(btnUp); //Lesen des Status des Tasters.
 statusBtnDown = digitalRead(btnDown); //Lesen des Status des Tasters.
 statusBtnReset = digitalRead(btnReset); //Lesen des Status des Tasters.

 Serial.print("statusRun =>");
 Serial.println(statusRun);

 if(!statusRun){
    if(statusBtnUp == LOW && activeNeoPixel < (numPixels-1)){ 
      activeNeoPixel++;
    }

    if(statusBtnDown == LOW && activeNeoPixel >= 0){ 
      activeNeoPixel--;
    }
  } else {
     Serial.print("activeNeoPixel =>");
     Serial.println(activeNeoPixel);
    
     double timeInMillis = activeNeoPixel + 1;
     timeInMillis = timeInMillis * 30;
     timeInMillis = timeInMillis * 1000; 
     
     Serial.print("timeInMillis =>");
     Serial.println(timeInMillis);
     
     
     Serial.print("timerCounter =>");
     Serial.println(timerCounter);

      //Wenn die Zeit abgelaufen ist.
      if(timerCounter >= timeInMillis){
        entferneTeeBeutel();
      } else {
        timerCounter = timerCounter +delayTime;
        double pixelForBlue = 0;
        if(timerCounter >0 && timerCounter < 30000){
          pixelForBlue = 0;
        } else {
            pixelForBlue = timerCounter / 30000;
            pixelForBlue = round(pixelForBlue);
        }
        Serial.print("pixelForBlue =>");
            Serial.println(pixelForBlue);
         int pixel = 0;
         for(pixel = 0; pixel <= pixelForBlue; pixel++) { 
            strip.setPixelColor(pixel, blue); 
          } 
        strip.show(); //Anzeigen
      }
  }
  
  if(statusBtnReset == HIGH){ 
     digitalWrite(btnReset,LOW);
     Serial.print("statusBtnReset =>");
     Serial.println(statusBtnReset);
    if(statusRun){
      reset(); 
    } else {
      statusRun = true;
    }
  }
 delay(delayTime); 
}

void entferneTeeBeutel(){
  hebeArm();
  delay(1000);
  drehArm();
  delay(1000);
  senkeArm();
  delay(1000);
  statusRun = false;
}

void reset(){
   defaultServoStellung();
   statusRun = false;
   activeNeoPixel = 0;
   timerCounter = 0;
}

void hebeArm(){
   for(position = 0; position <= 45; position++) { 
    hebeservo.write(position); 
    delay(servoWaitTime); //Pause
  } 
  Serial.println("hebeArm -> write 45");
}

void senkeArm(){
  for(position = 45; position > 0; position--) { 
    hebeservo.write(position); 
    delay(servoWaitTime); //Pause
  } 
  Serial.println("senkeArm -> write 0");
}

void drehArm(){
   for(position = 0; position <= 45; position++) { 
    drehservo.write(position); 
    delay(servoWaitTime); //Pause
  } 
  Serial.println("drehArm -> write 90");
 
}



